/*
 Copyright (c) 2017 CommonsWare, LLC
 Licensed under the Apache License, Version 2.0 (the "License"); you may not
 use this file except in compliance with the License. You may obtain	a copy
 of the License at http://www.apache.org/licenses/LICENSE-2.0. Unless required
 by applicable law or agreed to in writing, software distributed under the
 License is distributed on an "AS IS" BASIS,	WITHOUT	WARRANTIES OR CONDITIONS
 OF ANY KIND, either express or implied. See the License for the specific
 language governing permissions and limitations under the License.
 */

package com.commonsware.conference;

import android.support.test.InstrumentationRegistry;
import android.support.test.runner.AndroidJUnit4;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

@RunWith(AndroidJUnit4.class)
public class RoomTests {
  private ConferenceStore store;

  @Before
  public void setUp() {
    store=ConferenceDatabase
      .get(InstrumentationRegistry.getTargetContext(), true)
      .store();
  }

  @Test
  public void simpleTrack() {
    final Track track=new Track("Android", "Sorcerer's Apprentice 3");
    final Long trackId=store.insert(track);

    final List<Track> tracks=store.allTracks();

    assertEquals(1, tracks.size());
    assertContent(track, tracks.get(0));
    assertEquals(trackId, tracks.get(0).id);

    final Track fromDb=store.trackById(tracks.get(0).id);

    assertContent(track, fromDb);
    assertEquals(fromDb.id, tracks.get(0).id);
  }

  @Test
  public void snapshots() {
    final Track track=new Track("New Hotness", "Sorcerer's Apprentice 1");
    final ArrayList<Session> sessions=new ArrayList<>();

    sessions.add(new Session("Bootstrapping IoT Products", "Dave Smith",
      getTimeSlot(10, 30), 60));
    sessions.add(new Session("Pragmatic Machine Learning", "Nitya Narasimhan",
      getTimeSlot(14, 0), 60));
    sessions.add(new Session("Attacking an Android App", "Connor Tumbleson",
      getTimeSlot(17, 0), 60));

    final TrackSnapshot original=new TrackSnapshot();

    original.track=track;
    original.sessions=sessions;

    final Long trackId=store.insert(original);
    final TrackSnapshot fromDb=store.snapshotById(trackId);

    assertNotNull(fromDb);
    assertContent(track, fromDb.track);
    assertEquals(trackId, fromDb.track.id);
    assertEquals(sessions.size(), fromDb.sessions.size());

    for (int i=0;i<sessions.size();i++) {
      assertContent(sessions.get(i), fromDb.sessions.get(i));
    }

    final TrackSnapshot fromSingle=store.singleSnapshotById(trackId).blockingGet();

    assertNotNull(fromSingle);
    assertContent(track, fromSingle.track);
    assertEquals(trackId, fromSingle.track.id);
    assertEquals(sessions.size(), fromSingle.sessions.size());

    for (int i=0;i<sessions.size();i++) {
      assertContent(sessions.get(i), fromSingle.sessions.get(i));
    }
  }

  private Calendar getTimeSlot(int hour, int minute) {
    Calendar result=Calendar.getInstance();

    result.set(2017, Calendar.NOVEMBER, 11, hour, minute, 0);

    return result;
  }

  private void assertContent(Track left, Track right) {
    assertEquals(left.title, right.title);
    assertEquals(left.location, right.location);
  }

  private void assertContent(Session left, Session right) {
    assertEquals(left.title, right.title);
    assertEquals(left.presenter, right.presenter);
    assertEquals(left.startTime, right.startTime);
    assertEquals(left.duration, right.duration);
  }
}
