/*
 Copyright (c) 2017 CommonsWare, LLC
 Licensed under the Apache License, Version 2.0 (the "License"); you may not
 use this file except in compliance with the License. You may obtain	a copy
 of the License at http://www.apache.org/licenses/LICENSE-2.0. Unless required
 by applicable law or agreed to in writing, software distributed under the
 License is distributed on an "AS IS" BASIS,	WITHOUT	WARRANTIES OR CONDITIONS
 OF ANY KIND, either express or implied. See the License for the specific
 language governing permissions and limitations under the License.
 */

package com.commonsware.conference;

import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.TypeConverters;
import android.content.Context;
import android.text.Editable;
import com.commonsware.cwac.saferoom.SafeHelperFactory;

@Database(version=1, entities = {Track.class, Session.class})
@TypeConverters({TypeTransmogrifiers.class})
abstract public class ConferenceSafeDatabase extends RoomDatabase {
  public abstract ConferenceStore store();

  private static final String DB_NAME="safe.db";

  public static ConferenceSafeDatabase create(Context ctxt, Editable passphrase,
                                              boolean memoryOnly) {
    Builder<ConferenceSafeDatabase> b;

    if (memoryOnly) {
      b=Room.inMemoryDatabaseBuilder(ctxt.getApplicationContext(),
        ConferenceSafeDatabase.class);
    }
    else {
      b=Room.databaseBuilder(ctxt.getApplicationContext(), ConferenceSafeDatabase.class,
        DB_NAME);
    }

    b.openHelperFactory(SafeHelperFactory.fromUser(passphrase));

    return(b.build());
  }
}
