/*
 Copyright (c) 2017 CommonsWare, LLC
 Licensed under the Apache License, Version 2.0 (the "License"); you may not
 use this file except in compliance with the License. You may obtain	a copy
 of the License at http://www.apache.org/licenses/LICENSE-2.0. Unless required
 by applicable law or agreed to in writing, software distributed under the
 License is distributed on an "AS IS" BASIS,	WITHOUT	WARRANTIES OR CONDITIONS
 OF ANY KIND, either express or implied. See the License for the specific
 language governing permissions and limitations under the License.
 */

package com.commonsware.conference;

import android.arch.persistence.room.Dao;
import android.arch.persistence.room.Insert;
import android.arch.persistence.room.Query;
import android.arch.persistence.room.Transaction;
import java.util.ArrayList;
import java.util.List;
import io.reactivex.Single;

@Dao
abstract class ConferenceStore {
  @Insert
  abstract void insert(List<Session> sessions);

  @Insert
  abstract long insert(Track tracks);

  @Query("SELECT * FROM tracks")
  abstract List<Track> allTracks();

  @Query("SELECT * FROM tracks WHERE ID = :id")
  abstract Track trackById(Long id);

  @Query("SELECT * FROM sessions WHERE trackId=:trackId")
  abstract List<Session> sessionsForTrack(Long trackId);

  @Transaction
  @Query("SELECT * FROM tracks WHERE ID = :id")
  abstract TrackSnapshot snapshotById(Long id);

  @Transaction
  long insert(TrackSnapshot snapshot) {
    long trackId=insert(snapshot.track);

    ArrayList<Session> sessions=new ArrayList<>(snapshot.sessions.size());

    for (Session session : snapshot.sessions) {
      sessions.add(new Session(session, trackId));
    }

    insert(sessions);

    return(trackId);
  }

  @Transaction
  @Query("SELECT * FROM tracks WHERE ID = :id")
  abstract Single<TrackSnapshot> singleSnapshotById(Long id);
}
