/*
 Copyright (c) 2017 CommonsWare, LLC
 Licensed under the Apache License, Version 2.0 (the "License"); you may not
 use this file except in compliance with the License. You may obtain	a copy
 of the License at http://www.apache.org/licenses/LICENSE-2.0. Unless required
 by applicable law or agreed to in writing, software distributed under the
 License is distributed on an "AS IS" BASIS,	WITHOUT	WARRANTIES OR CONDITIONS
 OF ANY KIND, either express or implied. See the License for the specific
 language governing permissions and limitations under the License.
 */

package com.commonsware.conference;

import android.arch.persistence.room.Entity;
import android.arch.persistence.room.ForeignKey;
import android.arch.persistence.room.Ignore;
import android.arch.persistence.room.Index;
import android.arch.persistence.room.PrimaryKey;
import android.support.annotation.NonNull;
import java.util.Calendar;
import static android.arch.persistence.room.ForeignKey.CASCADE;

@Entity(tableName="sessions",
  foreignKeys=@ForeignKey(
    entity=Track.class,
    parentColumns="id",
    childColumns="trackId",
    onDelete=CASCADE),
  indices=@Index(value="trackId")
)
class Session {
  @PrimaryKey(autoGenerate=true)
  final Long id;

  final Long trackId;
  @NonNull final String title;
  @NonNull final String presenter;
  @NonNull final Calendar startTime;
  final int duration;

  @Ignore
  Session(@NonNull String title, @NonNull String presenter,
          @NonNull Calendar startTime, @NonNull int duration) {
    this(null, null, title, presenter, startTime, duration);
  }

  @Ignore
  Session(@NonNull Session original, @NonNull Long trackId) {
    this(original.id, trackId, original.title, original.presenter,
      original.startTime, original.duration);
  }

  Session(Long id, Long trackId, @NonNull String title,
          @NonNull String presenter, @NonNull Calendar startTime,
          @NonNull int duration) {
    this.id=id;
    this.trackId=trackId;
    this.title=title;
    this.presenter=presenter;
    this.startTime=startTime;
    this.duration=duration;
  }
}
